==> zio-aws-servicecatalog_2.13-5.17.116.1-sources.jar: zio/aws/servicecatalog/model/DescribeProvisioningArtifactResponse.scala <==
package zio.aws.servicecatalog.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.servicecatalog.model.primitives.{
  ProvisioningArtifactInfoValue,
  ProvisioningArtifactInfoKey
}
import scala.jdk.CollectionConverters._
final case class DescribeProvisioningArtifactResponse(
    provisioningArtifactDetail: Option[
      zio.aws.servicecatalog.model.ProvisioningArtifactDetail
    ] = None,
    info: Option[
      Map[ProvisioningArtifactInfoKey, ProvisioningArtifactInfoValue]
    ] = None,
    status: Option[zio.aws.servicecatalog.model.Status] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.servicecatalog.model.DescribeProvisioningArtifactResponse = {
    import DescribeProvisioningArtifactResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.servicecatalog.model.DescribeProvisioningArtifactResponse
      .builder()
      .optionallyWith(
        provisioningArtifactDetail.map(value => value.buildAwsValue())
      )(_.provisioningArtifactDetail)
      .optionallyWith(
        info.map(value =>
          value
            .map({ case (key, value) =>
              (ProvisioningArtifactInfoKey.unwrap(
                key
              ): java.lang.String) -> (ProvisioningArtifactInfoValue
                .unwrap(value): java.lang.String)
            })
            .asJava
        )
      )(_.info)
      .optionallyWith(status.map(value => value.unwrap))(_.status)
      .build()
  }
  def asReadOnly
      : zio.aws.servicecatalog.model.DescribeProvisioningArtifactResponse.ReadOnly =
    zio.aws.servicecatalog.model.DescribeProvisioningArtifactResponse
      .wrap(buildAwsValue())
}
object DescribeProvisioningArtifactResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.servicecatalog.model.DescribeProvisioningArtifactResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.servicecatalog.model.DescribeProvisioningArtifactResponse =
      zio.aws.servicecatalog.model.DescribeProvisioningArtifactResponse(
        provisioningArtifactDetail.map(value => value.asEditable),
        info.map(value => value),
        status.map(value => value)
      )
    def provisioningArtifactDetail: Option[
      zio.aws.servicecatalog.model.ProvisioningArtifactDetail.ReadOnly
    ]
    def info: Option[
      Map[ProvisioningArtifactInfoKey, ProvisioningArtifactInfoValue]
    ]
    def status: Option[zio.aws.servicecatalog.model.Status]
    def getProvisioningArtifactDetail: ZIO[
      Any,
      AwsError,
      zio.aws.servicecatalog.model.ProvisioningArtifactDetail.ReadOnly
    ] = AwsError.unwrapOptionField(
      "provisioningArtifactDetail",
      provisioningArtifactDetail
    )
    def getInfo: ZIO[Any, AwsError, Map[
      ProvisioningArtifactInfoKey,
      ProvisioningArtifactInfoValue
    ]] = AwsError.unwrapOptionField("info", info)
    def getStatus: ZIO[Any, AwsError, zio.aws.servicecatalog.model.Status] =
      AwsError.unwrapOptionField("status", status)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.servicecatalog.model.DescribeProvisioningArtifactResponse
  ) extends zio.aws.servicecatalog.model.DescribeProvisioningArtifactResponse.ReadOnly {
    override val provisioningArtifactDetail: Option[
      zio.aws.servicecatalog.model.ProvisioningArtifactDetail.ReadOnly
    ] = scala
      .Option(impl.provisioningArtifactDetail())
      .map(value =>
        zio.aws.servicecatalog.model.ProvisioningArtifactDetail.wrap(value)
      )
    override val info: Option[
      Map[ProvisioningArtifactInfoKey, ProvisioningArtifactInfoValue]
    ] = scala
      .Option(impl.info())
      .map(value =>
        value.asScala
          .map({ case (key, value) =>
            zio.aws.servicecatalog.model.primitives.ProvisioningArtifactInfoKey(
              key
            ) -> zio.aws.servicecatalog.model.primitives
              .ProvisioningArtifactInfoValue(value)
          })
          .toMap
      )
    override val status: Option[zio.aws.servicecatalog.model.Status] = scala
      .Option(impl.status())
      .map(value => zio.aws.servicecatalog.model.Status.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.servicecatalog.model.DescribeProvisioningArtifactResponse
  ): zio.aws.servicecatalog.model.DescribeProvisioningArtifactResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-servicecatalog_2.13-5.17.267.6-sources.jar: zio/aws/servicecatalog/model/DescribeProvisioningArtifactResponse.scala <==
package zio.aws.servicecatalog.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import zio.aws.servicecatalog.model.primitives.{
  ProvisioningArtifactInfoValue,
  ProvisioningArtifactInfoKey
}
import scala.jdk.CollectionConverters._
final case class DescribeProvisioningArtifactResponse(
    provisioningArtifactDetail: Optional[
      zio.aws.servicecatalog.model.ProvisioningArtifactDetail
    ] = Optional.Absent,
    info: Optional[
      Map[ProvisioningArtifactInfoKey, ProvisioningArtifactInfoValue]
    ] = Optional.Absent,
    status: Optional[zio.aws.servicecatalog.model.Status] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.servicecatalog.model.DescribeProvisioningArtifactResponse = {
    import DescribeProvisioningArtifactResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.servicecatalog.model.DescribeProvisioningArtifactResponse
      .builder()
      .optionallyWith(
        provisioningArtifactDetail.map(value => value.buildAwsValue())
      )(_.provisioningArtifactDetail)
      .optionallyWith(
        info.map(value =>
          value
            .map({ case (key, value) =>
              (ProvisioningArtifactInfoKey.unwrap(
                key
              ): java.lang.String) -> (ProvisioningArtifactInfoValue
                .unwrap(value): java.lang.String)
            })
            .asJava
        )
      )(_.info)
      .optionallyWith(status.map(value => value.unwrap))(_.status)
      .build()
  }
  def asReadOnly
      : zio.aws.servicecatalog.model.DescribeProvisioningArtifactResponse.ReadOnly =
    zio.aws.servicecatalog.model.DescribeProvisioningArtifactResponse
      .wrap(buildAwsValue())
}
object DescribeProvisioningArtifactResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.servicecatalog.model.DescribeProvisioningArtifactResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.servicecatalog.model.DescribeProvisioningArtifactResponse =
      zio.aws.servicecatalog.model.DescribeProvisioningArtifactResponse(
        provisioningArtifactDetail.map(value => value.asEditable),
        info.map(value => value),
        status.map(value => value)
      )
    def provisioningArtifactDetail: Optional[
      zio.aws.servicecatalog.model.ProvisioningArtifactDetail.ReadOnly
    ]
    def info: Optional[
      Map[ProvisioningArtifactInfoKey, ProvisioningArtifactInfoValue]
    ]
    def status: Optional[zio.aws.servicecatalog.model.Status]
    def getProvisioningArtifactDetail: ZIO[
      Any,
      AwsError,
      zio.aws.servicecatalog.model.ProvisioningArtifactDetail.ReadOnly
    ] = AwsError.unwrapOptionField(
      "provisioningArtifactDetail",
      provisioningArtifactDetail
    )
    def getInfo: ZIO[Any, AwsError, Map[
      ProvisioningArtifactInfoKey,
      ProvisioningArtifactInfoValue
    ]] = AwsError.unwrapOptionField("info", info)
    def getStatus: ZIO[Any, AwsError, zio.aws.servicecatalog.model.Status] =
      AwsError.unwrapOptionField("status", status)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.servicecatalog.model.DescribeProvisioningArtifactResponse
  ) extends zio.aws.servicecatalog.model.DescribeProvisioningArtifactResponse.ReadOnly {
    override val provisioningArtifactDetail: Optional[
      zio.aws.servicecatalog.model.ProvisioningArtifactDetail.ReadOnly
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.provisioningArtifactDetail())
      .map(value =>
        zio.aws.servicecatalog.model.ProvisioningArtifactDetail.wrap(value)
      )
    override val info: Optional[
      Map[ProvisioningArtifactInfoKey, ProvisioningArtifactInfoValue]
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.info())
      .map(value =>
        value.asScala
          .map({ case (key, value) =>
            zio.aws.servicecatalog.model.primitives.ProvisioningArtifactInfoKey(
              key
            ) -> zio.aws.servicecatalog.model.primitives
              .ProvisioningArtifactInfoValue(value)
          })
          .toMap
      )
    override val status: Optional[zio.aws.servicecatalog.model.Status] =
      zio.aws.core.internal
        .optionalFromNullable(impl.status())
        .map(value => zio.aws.servicecatalog.model.Status.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.servicecatalog.model.DescribeProvisioningArtifactResponse
  ): zio.aws.servicecatalog.model.DescribeProvisioningArtifactResponse.ReadOnly =
    new Wrapper(impl)
}
